@@ -27,7 +27,8 @@ def test_get_name(okex_exchange):
 @pytest.mark.asyncio
 async def test_get_orders_parameters(okex_exchange):
     exchange = exchanges.OKEx(okex_exchange)
-    await create_order_tests.create_order_mocked_test(exchange,
-                                                      exchange_private_post_order_method_name="privatePostTradeOrder",
-                                                      exchange_request_referral_key="clOrdId",
-                                                      should_contains=True)
+    await create_order_tests.create_order_mocked_test_args(
+        exchange,
+        exchange_private_post_order_method_name="privatePostTradeOrder",
+        exchange_request_referral_key="clOrdId",
+        should_contains=True)
